[![Build Status](https://travis-ci.com/sunpip/Mandarina.svg?token=Lee4ZEjwb1BeBBACz4Hc&branch=master)](https://travis-ci.com/sunpip/Mandarina)

Mandarina
======
**Mandarina** is a friendly Data Science library for Python

## Functionality

At the moment, Mandarina provides the following modules:
- Csv file functions
- Random data generators 
- Code benchmarking tools
- Tools to work with files and directories
- Scheduling functions 

## License 
* Check the [LICENSE](https://github.com/sunpip/Mandarina/blob/master/LICENSE) file

## Authors

- Alen Frey

## Version 
* Version 0.0.5

## How to install
```shell script
pip install mandarina
```
